@@ -44,7 +44,7 @@ require Exporter;
 use vars qw(@ISA @EXPORT_OK);
 our @ISA = qw(Exporter);
 
-our @EXPORT = qw( $MYSQL_BIN_PATH $MYSQL $MYSQLADMIN $MYSQLHOTCOPY $MYSQL_WINDOWS $MYSQL_NIX $binLog $datadir $slave_load_tmpdir $mysql_version $mysql_server_os $have_innodb $innodb_shared_data_on_fs $innodb_log_dir @innodb_shared_data_files $mysql_shutdown &addMySQLParams &extractValue &shutdownMySQL &isSlave &stopSlave &startSlave &getMySQLVariables &checkForWrongHostInputs &checkForRemoteHost &checkForCompressEncryptPlugin &verifyInputs &checkDirs &initMySQL );
+our @EXPORT = qw( $MYSQL_BIN_PATH $MYSQL $MYSQLADMIN $MYSQLHOTCOPY $MYSQL_WINDOWS $MYSQL_NIX $binLog $datadir $slave_load_tmpdir $mysql_version $mysql_server_os $have_innodb $innodb_shared_data_on_fs $innodb_log_dir @innodb_shared_data_files $mysql_shutdown &addMySQLParams &extractValue &shutdownMySQL &isSlave &stopSlave &startSlave &getMySQLVariables &checkForWrongHostInputs &checkForRemoteHost &checkForCompressEncryptPlugin &verifyInputs &checkDirs &initMySQL $isMyDumper);
 
 our $MYSQL_BIN_PATH;
 our $MYSQL="mysql";
@@ -67,6 +67,7 @@ our $mysql_shutdown = 0;
 our $slaveStopped = 0;
 
 my $copyPluginSpecified = 0;
+our $isMyDumper=0;
 
 $inputs{"backup-level"}="0";
 $inputs{"backup-mode"}="raw";
@@ -588,6 +589,23 @@ sub checkForSnapshot()
 
 }
 
+# check for the logical backup
+sub checkForLogicalParallelBackup()
+{
+    if( defined $inputs{"backup-method-name"} && $inputs{"backup-method-name"} eq "mydumper"){
+        $isMyDumper = 1;
+    }
+    if(defined $inputs{"logical-parallel"} && $inputs{"logical-parallel"} eq "1"){
+        $isMyDumper = 1;
+    }
+    if($isMyDumper){
+        my $mydumper = "/usr/local/bin/mydumper";
+        if(! -f $mydumper){
+            &printAndDie("mydumper not found - $mydumper. Logical Parallel backup requires the mydumper tool\n");
+        }
+    }
+}
+
 sub checkForIHB()
 {
 	if( ! defined $inputs{"ihb-plugin"} ){
@@ -689,7 +707,9 @@ sub verifyInputs()
 		}
 		$inputs{"mysql-binpath"} = $MYSQL_BIN_PATH;
 	}
-
+    if( $action ne "restore" ){
+        &checkForLogicalParallelBackup();
+    }
 	if( defined $inputs{"compress-mysqldump-onthefly"} && $inputs{"compress-mysqldump-onthefly"} eq 1 ){
 		if( !defined $inputs{"compress"} || $inputs{"compress"} == 0 ){
 			$inputs{"compress"} = 1;
