@@ -18,6 +18,7 @@
 # Contact information: Zmanda Inc, 505 N Mathlida Ave, Suite 120
 # Sunnyvale, CA 94085, USA, or: http://www.zmanda.com
 #
+#
 
 #This plugin uses ssh and tar to copy data between the localhost and remote host
 # Command line parameters to the plugin are 
@@ -50,10 +51,12 @@ $ENV{"PATH"}="/usr/local/bin:/opt/csw/bin:/bin:/usr/bin:/sbin:/usr/sbin";
 
 
 my $SSH="ssh";
-my $TAR="tar";
+my @SSH_ARR;
+my $TAR="gtar";
 my $RM="rm";
 my $MKDIR="mkdir";
 my $LS="ls";
+my $compress="";
 
 
 my $MYSQL_BINPATH="/usr/bin";
@@ -116,8 +119,12 @@ sub getCopyParameters()
 	}
 	
 	my @suf;
+	$srcFile =~ s/^"//g;
+	$srcFile =~ s/"$//g;
         $srcDir = dirname( $srcFile );
         $srcFile = basename( $srcFile, @suf );
+	$srcDir = "\"$srcDir\"";
+	$srcFile = "\"$srcFile\"";
 	if( defined $opt{"create-link"} ){
 		$action = "create-link";
 	}else{
@@ -231,7 +238,14 @@ sub doCreateLinks()
 {
 	my $dir;
 	my $link;
-	my $tmpFile = "$srcDir/$srcFile";
+	my $sd = $srcDir;
+	$sd =~ s/^"//g;
+	$sd =~ s/"$//g;
+	
+	my $sf = $srcFile;
+	$sf =~ s/^"//g;
+	$sf =~ s/"$//g;
+	my $tmpFile = "$sd/$sf";
 	$host = $destHost;
 	unless( open( TP, $tmpFile ) ){
 		die "Unable to open link details file\n";
@@ -251,7 +265,7 @@ sub doCreateLinks()
 	}
 	close TP;
 	chmod( 0700, $tmpFile );
-	my $r = system( $SSH, "$REMOTE_USER\@$host", $MKDIR, $TMP_DIR );
+	my $r = system( @SSH_ARR, "$REMOTE_USER\@$host", $MKDIR, $TMP_DIR );
 	if( $r > 0 ){
 		unlink( $tmpFile );	
 		die( "Could not create directory $TMP_DIR on host $host" );
@@ -259,7 +273,7 @@ sub doCreateLinks()
 
 	my $f = basename($tmpFile);
 	my $d = dirname( $tmpFile);
-	$r = system( "$TAR --same-owner -cphszC $d $f | $SSH $REMOTE_USER\@$host $TAR --same-owner -xphszC $TMP_DIR" );
+	$r = system( "$TAR --same-owner $compress -f- -cphsC $d $f | $SSH $REMOTE_USER\@$host $TAR --same-owner $compress -f- -xphsC $TMP_DIR" );
 
 	unlink( $tmpFile );	
 	if( $r > 0 ){
@@ -277,7 +291,7 @@ sub doCreateLinks()
 sub doTar()
 {
 	my $cmd;
-	my $tarCmd = "$TAR --same-owner -phszC ";
+	my $tarCmd = "$TAR --same-owner $compress -f- -phsC ";
 	
 	my $fileList = $srcFile;
 	my $lsCmd = "";
@@ -313,16 +327,16 @@ sub doTar()
 # executes mysqlhotcopy on remote machine and streams the data back using tar
 sub doMySQLHotCopy()
 {
-	my $r = system( $SSH, "$REMOTE_USER\@$host", $MKDIR, $TMP_DIR );
+	my $r = system( @SSH_ARR, "$REMOTE_USER\@$host", $MKDIR, $TMP_DIR );
 	if( $r > 0 ){
 		die( "Could not create directory $TMP_DIR on host $host" );
 	}
-	$r = system( $SSH, "$REMOTE_USER\@$host", "$REMOTE_MYSQL_BINPATH/$MYSQLHOTCOPY", $params, $TMP_DIR );
+	$r = system( @SSH_ARR, "$REMOTE_USER\@$host", "$REMOTE_MYSQL_BINPATH/$MYSQLHOTCOPY", $params, $TMP_DIR );
 	if( $r > 0 ){
 		die( "mysqlhotcopy on host $host failed" );
 	}
 	
-	$r = system( "$SSH $REMOTE_USER\@$host $TAR --same-owner -cphszC $TMP_DIR . | $TAR --same-owner -xphszC $destDir" );
+	$r = system( "$SSH $REMOTE_USER\@$host $TAR --same-owner $compress -f- -cphsC $TMP_DIR . | $TAR --same-owner $compress -f- -xphsC $destDir" );
 	
 	&removeTmpDir();
 	if( $r > 0 ){
@@ -340,14 +354,14 @@ sub removeDir()
 {
 	my $s = basename( $_[0] );
 	my $d = dirname( $_[0] );
-	my $r = system( $SSH, "$REMOTE_USER\@$host", $RM, "-rf", $_[0] );
+	my $r = system( @SSH_ARR, "$REMOTE_USER\@$host", $RM, "-rf", $_[0] );
 	if( $r > 0 ){
 		print STDERR "WARNING: Could not remove directory $_[0] on host $host\n";
 		return;
 	}
 	if( $s eq "ZRM_MOUNTS" ){
 		# try to remove the parent directory in case it is empty
-		$r = system( $SSH, "$REMOTE_USER\@$host", "rmdir", $d );
+		$r = system( @SSH_ARR, "$REMOTE_USER\@$host", "rmdir", $d );
 	}
 }	
 
@@ -391,6 +405,16 @@ sub setUpConfParams()
         	chomp( @snapshotParamList );
         	close TMP;
 	}
+	if( defined $config{"compress-data-during-transport"} && $config{"compress-data-during-transport"} == 1 ){
+		$compress = "-z";
+	}
+
+	push @SSH_ARR, $SSH;
+	if( defined $config{"ssh-identity-file"} ){
+		$SSH .= " -i ".$config{"ssh-identity-file"};
+		push @SSH_ARR, "-i";
+		push @SSH_ARR, $config{"ssh-identity-file"};
+	}
 
 }
 
@@ -408,7 +432,7 @@ sub doSnapshotCommand()
 	close TMP;
 	my $tmp = File::Spec->tmpdir();
 	
-	my $r = system( $SSH, "$REMOTE_USER\@$host", $MKDIR, $TMP_DIR );
+	my $r = system( @SSH_ARR, "$REMOTE_USER\@$host", $MKDIR, $TMP_DIR );
 	if( $r > 0 ){
 		unlink( $fName );	
 		die( "Could not create directory $TMP_DIR on host $host" );
@@ -416,7 +440,7 @@ sub doSnapshotCommand()
 
 	my $f = basename($fName);
 	my $d = dirname( $fName);
-	$r = system( "$TAR --same-owner -cphszC $d $f | $SSH $REMOTE_USER\@$host $TAR --same-owner -xphszC $TMP_DIR" );
+	$r = system( "$TAR --same-owner $compress -f- -cphsC $d $f | $SSH $REMOTE_USER\@$host $TAR --same-owner $compress -f- -xphsC $TMP_DIR" );
 
 	unlink( $fName );	
 	if( $r > 0 ){
@@ -443,7 +467,7 @@ sub doCopyBetween()
 	my $tmp = File::Spec->tmpdir();
 	$host = $srcHost;
 	my $fName = tmpnam();
-	my $r = system( $SSH, "$REMOTE_USER\@$host", $MKDIR, $TMP_DIR );
+	my $r = system( @SSH_ARR, "$REMOTE_USER\@$host", $MKDIR, $TMP_DIR );
 	if( $r > 0 ){
 		unlink( $fName );	
 		die( "Could not create directory $TMP_DIR on host $host" );
@@ -452,7 +476,7 @@ sub doCopyBetween()
 	my $f = basename($fName);
 	
 	my $cn = "$TMP_DIR/$f";
-	$r = system( $SSH, "$REMOTE_USER\@$host", "touch", $cn );
+	$r = system( @SSH_ARR, "$REMOTE_USER\@$host", "touch", $cn );
 
 	if( $r > 0 ){
 		&removeTmpDir();
